# Generated by Django 3.1.3 on 2020-11-30 15:01

import castellum.utils.fields
import castellum.utils.forms
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import parler.fields
import parler.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0011_update_proxy_permissions'),
        ('auth', '0012_alter_user_first_name_max_length'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('pseudonyms', '0002_pseudonym_unique_subject_domain'),
    ]

    operations = [
        migrations.CreateModel(
            name='Study',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=254, verbose_name='Name')),
                ('contact_person', models.CharField(max_length=254, verbose_name='Responsible contact person')),
                ('principal_investigator', models.CharField(max_length=254, verbose_name='Principal Investigator')),
                ('affiliated_scientists', models.CharField(blank=True, max_length=254, verbose_name='Affiliated Scientists')),
                ('affiliated_research_assistants', models.CharField(blank=True, max_length=254, verbose_name='Affiliated Research Assistants')),
                ('description', models.TextField(blank=True, verbose_name='Description')),
                ('keywords', models.CharField(blank=True, max_length=254, verbose_name='Keywords')),
                ('previous_status', models.SmallIntegerField(choices=[(0, 'Edit'), (1, 'Execution'), (2, 'Finished')], default=0, verbose_name='Previous status')),
                ('status', models.SmallIntegerField(choices=[(0, 'Edit'), (1, 'Execution'), (2, 'Finished')], default=0, verbose_name='Status')),
                ('data_sensitivity', models.BooleanField(default=False, verbose_name='Contains sensitive data')),
                ('min_subject_count', models.PositiveIntegerField(default=0, verbose_name='Required number of subjects')),
                ('sessions_start', castellum.utils.fields.DateField(blank=True, null=True, verbose_name='Start of test sessions')),
                ('sessions_end', castellum.utils.fields.DateField(blank=True, null=True, verbose_name='End of test sessions')),
                ('exclusion_criteria', models.TextField(blank=True, verbose_name='Additional subject characteristics that should be verified during recruitment')),
                ('recruitment_text', models.TextField(blank=True, help_text='This text will be used during recruitment dialogue. Thus, please describe the study from the perspective of recruiters and potential participants: What is it about? How long will it take? Are there any potential benefits or risks for participants? If applicable, also present the amount of expense allowance and related requirements.', verbose_name='Recruitment text')),
                ('domain', models.CharField(default=None, editable=False, max_length=64, unique=True)),
                ('advanced_filtering', models.BooleanField(default=False, help_text='By default you can create only one filtergroup in which all the filters are joined by AND operator. Advanced filtering allows you to create multiple filtergroups which are joined by OR operator.', verbose_name='Advanced filtering')),
                ('custom_filter', models.CharField(blank=True, max_length=254, verbose_name='Custom filter')),
                ('is_exclusive', models.BooleanField(default=False, help_text='When set, this ensures that potential subjects for this study will not be recruited in other studies. Please note that this may hinder other researchers in finding enough participants.', verbose_name='Exclusive subjects')),
                ('complete_matches_only', models.BooleanField(default=False, help_text='By default, filters may include subjects with incomplete attributes. This feature is supposed to improve the quality of the database by asking recruiters to fill missing values on the go. Only allowing complete filter matches can speed up individual recruitments but may deteriorate the quality of the database as a whole. Furthermore, this reduces the number of potential subjects.', verbose_name='Complete filter matches only')),
                ('consent', castellum.utils.fields.RestrictedFileField(blank=True, upload_to='studies/consent/', verbose_name='Consent')),
                ('mail_subject', models.CharField(blank=True, max_length=254, verbose_name='E-mail subject')),
                ('mail_body', models.TextField(blank=True, help_text='Any "{name}"-tags included in the e-mail-body will automatically be replaced with the full name of the subject.', verbose_name='E-mail body')),
                ('email', models.EmailField(max_length=128, verbose_name='E-mail-address')),
                ('phone', castellum.utils.fields.PhoneNumberField(max_length=32, region=None, verbose_name='Phone number')),
                ('excluded_studies', models.ManyToManyField(blank=True, related_name='_study_excluded_studies_+', to='studies.Study', verbose_name='Excluded studies')),
                ('session_instructions', models.TextField(blank=True, help_text='Please describe any requirements for carrying out the sessions listed below. For example, specify time intervals between sessions that need to be considered for booking appointments.', verbose_name='Session instructions')),
                ('is_onetime_invitation', models.BooleanField(default=False, help_text='Use this if you want to skip the usual recruitment workflow and just send an email to subjects, e.g. to invite them to an anonymous online survey.', verbose_name='Is a one time invitation')),
                ('announce_status_changes', models.BooleanField(default=False, verbose_name='Announce status changes')),
                ('geo_filter', castellum.utils.fields.RestrictedFileField(blank=True, help_text='A GeoJSON file that contains only a single (multi)polygon. Only subjects who live inside this polygon will be considered for this study.', upload_to='studies/geofilters/', validators=[castellum.utils.forms.JsonFileValidator({'$defs': {'Feature': {'properties': {'geometry': {'oneOf': [{'$ref': '#/$defs/Polygon'}, {'$ref': '#/$defs/MultiPolygon'}]}, 'properties': {'oneOf': [{'type': 'null'}, {'type': 'object'}]}, 'type': {'enum': ['Feature'], 'type': 'string'}}, 'required': ['type', 'properties', 'geometry'], 'type': 'object'}, 'MultiPolygon': {'properties': {'coordinates': {'items': {'$ref': '#/$defs/MultiPolygon'}, 'type': 'array'}, 'type': {'enum': ['MultiPolygon'], 'type': 'string'}}, 'required': ['type', 'coordinates'], 'type': 'object'}, 'Polygon': {'properties': {'coordinates': {'$ref': '#/$defs/PolygonCoordinates'}, 'type': {'enum': ['Polygon'], 'type': 'string'}}, 'required': ['type', 'coordinates'], 'type': 'object'}, 'PolygonCoordinates': {'items': {'items': {'items': {'type': 'number'}, 'minItems': 2, 'type': 'array'}, 'minItems': 4, 'type': 'array'}, 'type': 'array'}}, '$schema': 'http://json-schema.org/draft-07/schema#'}, '#/$defs/Feature')], verbose_name='Geo filter file')),
            ],
            options={
                'ordering': ['name'],
                'permissions': [('access_study', 'Can access studies'), ('approve_study', 'Can approve studies')],
            },
        ),
        migrations.CreateModel(
            name='StudyType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('exclusion_criteria', models.TextField(blank=True, verbose_name='Additional subject characteristics that should be verified during recruitment')),
                ('data_sensitivity', models.BooleanField(default=False, verbose_name='Contains sensitive data')),
                ('export_key', models.CharField(blank=True, choices=[('Online', 'Online'), ('Behavioral lab', 'Behavioral lab'), ('MRI', 'MRI'), ('Simulation', 'Simulation'), ('EEG', 'EEG')], max_length=32, verbose_name='Export key')),
            ],
            options={
                'abstract': False,
            },
            bases=(parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='StudyGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150, unique=True, verbose_name='name')),
                ('permissions', models.ManyToManyField(blank=True, to='auth.Permission', verbose_name='permissions')),
            ],
        ),
        migrations.CreateModel(
            name='StudyMembership',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('groups', models.ManyToManyField(blank=True, related_name='_studymembership_groups_+', to='studies.StudyGroup')),
                ('study', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='studies.study')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'unique_together': {('study', 'user')},
            },
        ),
        migrations.AddField(
            model_name='study',
            name='members',
            field=models.ManyToManyField(through='studies.StudyMembership', to=settings.AUTH_USER_MODEL),
        ),
        migrations.CreateModel(
            name='StudyTypeTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(db_index=True, max_length=15, verbose_name='Language')),
                ('label', models.CharField(max_length=64, verbose_name='Label')),
                ('master', parler.fields.TranslationsForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='studies.studytype')),
            ],
            options={
                'verbose_name': 'study type Translation',
                'db_table': 'studies_studytype_translation',
                'db_tablespace': '',
                'managed': True,
                'default_permissions': (),
                'unique_together': {('language_code', 'master')},
            },
            bases=(parler.models.TranslatedFieldsModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='Resource',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128, verbose_name='Name')),
            ],
        ),
        migrations.CreateModel(
            name='StudyTypeEventFeed',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField(verbose_name='URL')),
                ('study_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='studies.studytype')),
                ('color', castellum.utils.fields.ColorField(max_length=7, verbose_name='Color')),
            ],
        ),
        migrations.CreateModel(
            name='StudySession',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('duration', models.PositiveIntegerField(verbose_name='Duration of a session in minutes')),
                ('study', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='studies.study')),
                ('name', models.CharField(max_length=128, verbose_name='Name')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='studies.resource', verbose_name='Resource')),
                ('type', models.ManyToManyField(blank=True, to='studies.StudyType', verbose_name='Type')),
                ('domain', models.CharField(default=None, editable=False, max_length=64, unique=True)),
                ('schedule_id', models.PositiveIntegerField(blank=True, null=True, unique=True, verbose_name='External schedule ID')),
            ],
        ),
    ]
